@@ -3,7 +3,7 @@ import logging
 from collections import OrderedDict
 from typing import Union
 
-from .commons import default_factories, first_in, wrap_val
+from .commons import Constant, default_factories, first_in, wrap_val
 from .fields import (
     FunctionCall,
     Map,
@@ -30,8 +30,8 @@ from .fields import (
 from .enum import Enum
 
 from .extfields import DateString
-from .mappers import Constant, DoNotSerialize, aggregate_serialization_mappers
-from .structures import ADDITIONAL_PROPERTIES, NoneField, Structure
+from .mappers import DoNotSerialize, aggregate_serialization_mappers
+from .structures import ADDITIONAL_PROPERTIES, NoneField, Structure, TypedPyDefaults
 
 SCHEMA_PATTERN_PROPERTIES = "patternProperties"
 SCHEMA_ADDITIONAL_PROPERTIES = "additionalProperties"
@@ -137,7 +137,10 @@ def structure_to_schema(structure, definitions_schema, serialization_mapper=None
         raise TypeError("Expected a Structure subclass")
     field_by_name = structure.get_all_fields_by_name()
     required = getattr(structure, "_required", list(field_by_name.keys()))
-    additional_props = getattr(structure, ADDITIONAL_PROPERTIES, True)
+
+    additional_props = getattr(
+        structure, ADDITIONAL_PROPERTIES, TypedPyDefaults.additional_properties_default
+    )
     mapper = aggregate_serialization_mappers(structure, serialization_mapper) or {}
     if getattr(structure, "_additional_serialization") != getattr(
         Structure, "_additional_serialization"
@@ -183,6 +186,8 @@ def structure_to_schema(structure, definitions_schema, serialization_mapper=None
                         default_raw() if callable(default_raw) else default_raw
                     )
                     sub_schema["default"] = default_val
+                    if mapped_key not in required:
+                        required.append(mapped_key)
                 properties[mapped_key] = sub_schema
         fields_schema.update(
             OrderedDict(
@@ -291,7 +296,7 @@ def schema_to_struct_code(
         else []
     )
     body += (
-        ["    _additionalProperties = False"]
+        ["    _additional_properties = False"]
         if not schema.get("additionalProperties", True)
         else []
     )
@@ -305,6 +310,8 @@ def schema_to_struct_code(
     if the_type == "object":
         properties = schema.get("properties", {})
         for (name, sch) in properties.items():
+            if "default" in sch and name in required:
+                required.remove(name)
             body += [
                 f"    {name} = {convert_to_field_code(sch, definitions_schema, additional_fields=additional_fields)}"
             ]
@@ -394,7 +401,7 @@ class StructureReferenceMapper(Mapper):
         body = []
         body += (
             [(ADDITIONAL_PROPERTIES, False)]
-            if not schema.get("additionalProperties", True)
+            if not schema.get(SCHEMA_ADDITIONAL_PROPERTIES, True)
             else []
         )
         required = schema.get("required", None)
